==> enterprisemodules-wls_config-3.0.21.tar.gz: enterprisemodules-wls_config-3.0.21/lib/puppet/type/wls_server.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.dirname(__FILE__)
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../../../easy_type/lib')
require 'puppet/parameter/boolean'
require 'puppet_x/enterprisemodules/weblogic/core'
# rubocop: disable Metrics/ModuleLength
# doc
module Puppet
  Type.newtype(:wls_server) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage server in an WebLogic domain.

    Here is an example on how you should use this:

        wls_server { 'wlsServer2':
          ensure                            => 'present',
          arguments                         => '-XX:PermSize=256m -XX:MaxPermSize=256m -Xms752m -Xmx752m -Dweblogic.Stdout=/var/log/weblogic/wlsServer2.out -Dweblogic.Stderr=/var/log/weblogic/wlsServer2_err.out',
          jsseenabled                       => '0',
          listenaddress                     => '10.10.10.200',
          listenport                        => '8001',
          listenportenabled                 => '1',
          log_file_min_size                 => '2000',
          log_filecount                     => '10',
          log_number_of_files_limited       => '1',
          log_rotate_logon_startup          => '1',
          log_rotationtype                  => 'bySize',
          logfilename                       => '/var/log/weblogic/wlsServer2.log',
          log_datasource_filename           => 'logs/datasource.log',
          log_http_filename                 => 'logs/access.log',
          log_http_format                   => 'date time cs-method cs-uri sc-status',
          log_http_format_type              => 'common',
          log_http_file_count               => '10',
          log_http_number_of_files_limited  => '0',
          log_redirect_stderr_to_server     => '0',
          log_redirect_stdout_to_server     => '0',
          logintimeout                      => '5000',
          restart_max                       => '2',
          machine                           => 'Node2',
          sslenabled                        => '1',
          sslhostnameverificationignored    => '1',
          ssllistenport                     => '8201',
          two_way_ssl                       => '0',
          client_certificate_enforced       => '0',
          default_file_store                => '/path/to/default_file_store/',
          max_message_size                  => '25000000',
          weblogic_plugin_enabled           => '1',
        }

    In this example you are managing a managed server in the default domain. When you want to
    manage a managed server in a specific domain, you can use:

        wls_server { 'my_domain/wlsServer1':
          ensure                            => 'present',
          arguments                         => '-XX:PermSize=256m -XX:MaxPermSize=256m -Xms752m -Xmx752m -Dweblogic.Stdout=/var/log/weblogic/wlsServer1.out -Dweblogic.Stderr=/var/log/weblogic/wlsServer1_err.out',
          jsseenabled                       => '0',
          listenaddress                     => '10.10.10.100',
          listenport                        => '8001',
          listenportenabled                 => '1',
          machine                           => 'Node1',
          sslenabled                        => '0',
          tunnelingenabled                  => '0',
          max_message_size                  => '10000000',
        }

    EOD

    on_create do
      create_boot_properties_file if create_boot_properties
      create_resource
      nil
    end

    on_destroy do
      Puppet.info "destroy #{name} "
      wls_config  = Puppet_X::EnterpriseModules::WebLogic::Tree.new(domain)
      path = "#{bean_path.subst(to_hash)}/#{server_name}"
      wls_config.edit
      wls_config.clear("#{path}/Cluster")
      wls_config.clear("#{path}/Machine")
      wls_config.save
      wls_config.edit
      destroy_resource
      domain_path = wls_config.get('/RootDirectory')
      dir = "#{domain_path}/servers/#{server_name}"
      Puppet.info "Removing directory with content #{dir}"
      FileUtils.rm_rf(dir)
      nil
    end

    bean_type('Server')

    ensurable
    parameter :domain
    parameter :name
    parameter :server_name

    parameter :custom_identity_keystore_passphrase
    parameter :custom_identity_privatekey_passphrase
    parameter :trust_keystore_passphrase
    parameter :create_boot_properties
    parameter :timeout

    property :tunnelingenabled

    property :trust_keystore_file
    property :custom_identity_keystore_filename
    property :custom_identity_alias

    property :ssllistenport
    property :sslenabled
    property :listenaddress
    property :listenport
    property :listenportenabled
    property :machine
    property :classpath
    property :arguments
    property :bea_home
    property :logintimeout

    property :frontendhost
    property :frontendhttpport
    property :frontendhttpsport

    property :logfilename
    property :log_file_min_size
    property :log_number_of_files_limited
    property :log_filecount
    property :log_rotationtype
    property :log_rotate_logon_startup
    property :log_datasource_filename
    property :log_redirect_stdout_to_server
    property :log_redirect_stderr_to_server
    property :log_date_pattern

    property :log_http_filename
    property :log_http_format_type
    property :log_http_format
    property :log_http_file_count
    property :log_http_number_of_files_limited

    property :sslhostnameverificationignored
    property :two_way_ssl
    property :client_certificate_enforced
    property :jsseenabled
    property :default_file_store
    property :synchronous_write_policy
    property :max_message_size
    property :restart_max
    property :weblogic_plugin_enabled

    property :custom_identity
    property :useservercerts
    property :sslhostnameverifier

    property :auto_restart
    property :autokillwfail

    property :server_parameters

    #
    # The extra properties are only enabled when they are explicitly enabled in the wls_setting
    # for the current domain. Else they are ignored.
    #
    extraproperties do
      property :accept_backlog
      property :add_work_manager_threads_by_cpu_count
      property :administration_port
      property :administration_protocol
      property :admin_reconnect_interval_seconds
      property :allow_shrinking_priority_request_queue
      property :auto_kill_if_failed
      property :auto_migration_enabled
      property :classpath_servlet_disabled
      property :client_cert_proxy_enabled
      property :cluster_weight
      property :coherence_cluster_system_resource
      property :com_enabled
      property :complete_com_message_timeout
      property :complete_http_message_timeout
      property :complete_iiop_message_timeout
      property :complete_message_timeout
      property :complete_t3_message_timeout
      property :complete_write_timeout
      property :connect_timeout
      property :custom_identity_key_store_file_name
      property :custom_identity_key_store_pass_phrase
      property :custom_identity_key_store_type
      property :custom_trust_key_store_file_name
      property :custom_trust_key_store_pass_phrase
      property :custom_trust_key_store_type
      property :default_iiop_password
      property :default_iiop_user
      property :default_internal_servlets_disabled
      property :default_protocol
      property :default_secure_protocol
      property :default_tgiop_password
      property :default_tgiop_user
      property :dgc_idle_periods_until_timeout
      property :external_dns_name
      property :extra_ejbc_options
      property :extra_rmic_options
      property :gathered_writes_enabled
      property :graceful_shutdown_timeout
      property :health_check_interval_seconds
      property :health_check_start_delay_seconds
      property :health_check_timeout_seconds
      property :hosts_migratable_services
      property :httpd_enabled
      property :http_trace_support_enabled
      property :idle_connection_timeout
      property :idle_iiop_connection_timeout
      property :idle_periods_until_timeout
      property :ignore_sessions_during_shutdown
      property :iiop_enabled
      property :iiop_tx_mechanism
      property :instrument_stack_trace_enabled
      property :interface_address
      property :java_compiler_post_class_path
      property :java_compiler_pre_class_path
      property :java_compiler
      property :java_standard_trust_key_store_pass_phrase
      property :jdbcllr_table_name
      property :jdbc_logging_enabled
      property :jdbc_login_timeout_seconds
      property :jms_default_connection_factories_enabled
      property :jndi_transportable_object_factory_list
      property :key_stores
      property :listen_address
      property :listen_delay_secs
      property :listeners_bind_early
      property :listen_port_enabled
      property :listen_port
      property :listen_thread_start_delay_secs
      property :log_buffer_size_kb
      property :log_domain_log_broadcaster_buffer_size
      property :log_domain_log_broadcast_filter
      property :log_domain_log_broadcast_severity
      property :log_file_count
      property :log_file_name
      property :log_file_time_span
      property :login_timeout_millis
      property :log_log4j_logging_enabled
      property :log_file_filter
      property :log_file_rotation_dir
      property :log_file_severity
      property :log_logger_severity_properties
      property :log_logger_severity
      property :log_memory_buffer_filter
      property :log_memory_buffer_severity
      property :log_memory_buffer_size
      property :log_notes
      property :log_platform_logger_levels
      property :log_redirect_stderr_to_server_log_enabled
      property :log_redirect_stdout_to_server_log_enabled
      property :log_remote_exceptions_enabled
      property :log_rotate_log_on_startup
      property :log_rotation_time
      property :log_rotation_type
      property :log_server_logging_bridge_use_parent_loggers_enabled
      property :log_stdout_filter
      property :log_stdout_format
      property :log_stdout_log_stack
      property :log_stdout_severity
      property :low_memory_gc_threshold
      property :low_memory_granularity_level
      property :low_memory_sample_size
      property :low_memory_time_interval
      property :managed_server_independence_enabled
      property :max_com_message_size
      property :max_http_message_size
      property :max_iiop_message_size
      property :max_open_sock_count
      property :max_t3_message_size
      property :message_id_prefix_enabled
      property :messaging_bridge_thread_pool_size
      property :msi_file_replication_enabled
      property :muxer_class
      property :native_io_enabled
      property :nm_socket_create_timeout_in_millis
      property :notes
      property :outbound_enabled
      property :outbound_private_key_enabled
      property :period_length
      property :preferred_secondary_group
      property :print_stack_trace_in_production
      property :reliable_delivery_policy
      property :replication_group
      property :replication_ports
      property :resolve_dns_name
      property :restart_delay_seconds
      property :restart_interval_seconds
      property :reverse_dns_allowed
      property :scattered_reads_enabled
      property :server_life_cycle_timeout_val
      property :server_template
      property :server_version
      property :socket_buffer_size_as_chunk_size
      property :socket_readers
      property :ssl_accept_kss_demo_certs_enabled
      property :ssl_allow_unencrypted_null_cipher
      property :ssl_cert_authenticator
      property :ssl_ciphersuites
      property :ssl_client_cert_alias
      property :ssl_client_certificate_enforced
      property :ssl_client_cert_private_key_pass_phrase
      property :ssl_enabled
      property :ssl_export_key_lifespan
      property :ssl_hostname_verification_ignored
      property :ssl_hostname_verifier
      property :ssl_identity_and_trust_locations
      property :ssl_inbound_certificate_validation
      property :ssl_jsse_enabled
      property :ssl_listen_port
      property :ssl_login_timeout_millis
      property :ssl_notes
      property :ssl_outbound_certificate_validation
      property :ssl_outbound_private_key_alias
      # property :ssl_outbound_private_key_pass_phrase
      property :ssl_peer_validation_enforced
      property :ssl_server_certificate_chain_file_name
      property :ssl_server_certificate_file_name
      property :ssl_server_key_file_name
      property :ssl_server_private_key_alias
      property :ssl_server_private_key_pass_phrase
      property :ssl_rejection_logging_enabled
      property :ssl_trusted_ca_file_name
      property :ssl_two_way_ssl_enabled
      property :ssl_use_client_cert_for_outbound
      property :ssl_use_server_certs
      property :staging_directory_name
      property :staging_mode
      property :startup_mode
      property :startup_timeout
      property :stuck_thread_max_time
      property :stuck_thread_timer_interval
      property :tgiop_enabled
      property :thread_pool_percent_socket_readers
      property :transaction_log_file_prefix
      property :transaction_log_file_write_policy
      property :tunneling_client_ping_secs
      property :tunneling_client_timeout_secs
      property :tunneling_enabled
      property :upload_directory_name
      property :use81_style_execute_queues
      property :use_concurrent_queue_for_request_manager
      property :use_detailed_thread_name
      property :use_enhanced_increment_advisor
      property :use_enhanced_priority_queue_for_request_manager
      property :use_fusion_for_llr
      property :verbose_ejb_deployment_enabled
      property :virtual_machine_name
      property :xml_entity_cache
      property :xml_registry
      #
      # Weblogic 12.2.1 new properties
      #
      property :buzz_address
      property :buzz_enabled
      property :buzz_port
      property :eager_thread_local_cleanup
      property :jms_connection_factory_unmapped_res_ref_mode
      property :log_date_format_pattern
      property :log_monitoring_enabled
      property :log_monitoring_interval_secs
      property :log_monitoring_throttle_message_length
      property :log_monitoring_throttle_threshold
      property :log_tags
      property :max_concurrent_long_running_requests
      property :max_concurrent_new_threads
      property :num_of_retries_before_msi_mode
      property :retry_interval_before_msi_mode
      property :ssl_minimum_tls_protocol_version
      property :ssl_ss_lv2_hello_enabled
      property :ssl_tags
      property :tags
      #
      # Overload protection
      #
      property :overload_panic_action
      property :overload_shared_capacity_for_work_managers
      property :overload_failure_action
      property :overload_server_failure_trigger
      property :overload_free_memory_percent_low_threshold
      property :overload_free_memory_percent_high_threshold
      property :overload_notes
      property :overload_tags
    end

    add_title_attributes(:server_name)

    private

    def create_boot_properties_file
      wls_config  = Puppet_X::EnterpriseModules::WebLogic::Tree.new(domain)
      domain_path = wls_config.get('/RootDirectory')
      os_user     = configuration.fetch(domain).fetch('user')
      username    = configuration.fetch(domain).fetch('weblogic_user')
      password    = configuration.fetch(domain).fetch('weblogic_password')
      top_dir     = "#{domain_path}/servers/#{server_name}"
      group_uid   = File.stat(domain_path).gid
      os_group    = Etc.getgrgid(group_uid).name
      dir_name    = "#{top_dir}/security"
      file_name   = "#{dir_name}/boot.properties"
      FileUtils.mkdir_p(dir_name)
      File.open(file_name, 'w') do |file|
        file.write("username=#{username}\n")
        file.write("password=#{password}\n")
      end
      Puppet.info "Creating #{file_name}."
      FileUtils.chown_R(os_user, os_group, top_dir)
      FileUtils.chmod_R(0o750, top_dir)
    end
  end
end
#

==> enterprisemodules-wls_config-3.2.2.tar.gz: enterprisemodules-wls_config-3.2.2/lib/puppet/type/wls_server.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.dirname(__FILE__)
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../../../easy_type/lib')
require 'puppet/parameter/boolean'
require 'puppet_x/enterprisemodules/weblogic/core'
# rubocop: disable Metrics/ModuleLength
# doc
module Puppet
  Type.newtype(:wls_server) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage server in an WebLogic domain.

    Here is an example on how you should use this:

        wls_server { 'wlsServer2':
          ensure                            => 'present',
          arguments                         => '-XX:PermSize=256m -XX:MaxPermSize=256m -Xms752m -Xmx752m -Dweblogic.Stdout=/var/log/weblogic/wlsServer2.out -Dweblogic.Stderr=/var/log/weblogic/wlsServer2_err.out',
          jsseenabled                       => '0',
          listenaddress                     => '10.10.10.200',
          listenport                        => '8001',
          listenportenabled                 => 1,
          log_file_min_size                 => '2000',
          log_filecount                     => '10',
          log_number_of_files_limited       => 1,
          log_rotate_logon_startup          => 1,
          log_rotationtype                  => 'bySize',
          logfilename                       => '/var/log/weblogic/wlsServer2.log',
          log_datasource_filename           => 'logs/datasource.log',
          log_http_filename                 => 'logs/access.log',
          log_http_format                   => 'date time cs-method cs-uri sc-status',
          log_http_format_type              => 'common',
          log_http_file_count               => '10',
          log_http_number_of_files_limited  => '0',
          log_redirect_stderr_to_server     => '0',
          log_redirect_stdout_to_server     => '0',
          logintimeout                      => '5000',
          restart_max                       => '2',
          machine                           => 'Node2',
          sslenabled                        => 1,
          sslhostnameverificationignored    => 1,
          ssllistenport                     => '8201',
          two_way_ssl                       => '0',
          client_certificate_enforced       => '0',
          default_file_store                => '/path/to/default_file_store/',
          max_message_size                  => '25000000',
          weblogic_plugin_enabled           => 1,
        }

    In this example you are managing a managed server in the default domain. When you want to
    manage a managed server in a specific domain, you can use:

        wls_server { 'my_domain/wlsServer1':
          ensure                            => 'present',
          arguments                         => '-XX:PermSize=256m -XX:MaxPermSize=256m -Xms752m -Xmx752m -Dweblogic.Stdout=/var/log/weblogic/wlsServer1.out -Dweblogic.Stderr=/var/log/weblogic/wlsServer1_err.out',
          jsseenabled                       => '0',
          listenaddress                     => '10.10.10.100',
          listenport                        => '8001',
          listenportenabled                 => 1,
          machine                           => 'Node1',
          sslenabled                        => '0',
          tunnelingenabled                  => '0',
          max_message_size                  => '10000000',
        }

    EOD

    on_create do
      create_boot_properties_file if create_boot_properties
      create_resource
      nil
    end

    on_destroy do
      Puppet.info "destroy #{name} "
      wls_config  = Puppet_X::EnterpriseModules::WebLogic::Tree.new(domain)
      path = "#{bean_path.subst(to_hash)}/#{server_name}"
      wls_config.edit
      wls_config.clear("#{path}/Cluster")
      wls_config.clear("#{path}/Machine")
      wls_config.save
      wls_config.edit
      destroy_resource
      domain_path = wls_config.get('/RootDirectory')
      dir = "#{domain_path}/servers/#{server_name}"
      Puppet.info "Removing directory with content #{dir}"
      FileUtils.rm_rf(dir)
      nil
    end

    bean_type('Server')

    ensurable
    parameter :domain
    parameter :name
    parameter :server_name

    parameter :custom_identity_keystore_passphrase
    parameter :custom_identity_privatekey_passphrase
    parameter :trust_keystore_passphrase
    parameter :create_boot_properties
    parameter :timeout

    property :tunnelingenabled

    property :trust_keystore_file
    property :custom_identity_keystore_filename
    property :custom_identity_alias

    property :ssllistenport
    property :sslenabled
    property :listenaddress
    property :listenport
    property :listenportenabled
    property :machine
    property :classpath
    property :arguments
    property :bea_home
    property :logintimeout

    property :frontendhost
    property :frontendhttpport
    property :frontendhttpsport

    property :logfilename
    property :log_file_min_size
    property :log_number_of_files_limited
    property :log_filecount
    property :log_rotationtype
    property :log_rotate_logon_startup
    property :log_datasource_filename
    property :log_redirect_stdout_to_server
    property :log_redirect_stderr_to_server
    property :log_date_pattern

    property :log_http_filename
    property :log_http_format_type
    property :log_http_format
    property :log_http_file_count
    property :log_http_number_of_files_limited

    property :sslhostnameverificationignored
    property :two_way_ssl
    property :client_certificate_enforced
    property :jsseenabled
    property :default_file_store
    property :synchronous_write_policy
    property :max_message_size
    property :restart_max
    property :weblogic_plugin_enabled

    property :custom_identity
    property :useservercerts
    property :sslhostnameverifier

    property :auto_restart
    property :autokillwfail

    property :server_parameters

    #
    # The extra properties are only enabled when they are explicitly enabled in the wls_setting
    # for the current domain. Else they are ignored.
    #
    extraproperties do
      property :accept_backlog
      property :add_work_manager_threads_by_cpu_count
      property :administration_port
      property :administration_protocol
      property :admin_reconnect_interval_seconds
      property :allow_shrinking_priority_request_queue
      property :auto_kill_if_failed
      property :auto_migration_enabled
      property :classpath_servlet_disabled
      property :client_cert_proxy_enabled
      property :cluster_weight
      property :coherence_cluster_system_resource
      property :com_enabled
      property :complete_com_message_timeout
      property :complete_http_message_timeout
      property :complete_iiop_message_timeout
      property :complete_message_timeout
      property :complete_t3_message_timeout
      property :complete_write_timeout
      property :connect_timeout
      property :custom_identity_key_store_file_name
      property :custom_identity_key_store_pass_phrase
      property :custom_identity_key_store_type
      property :custom_trust_key_store_file_name
      property :custom_trust_key_store_pass_phrase
      property :custom_trust_key_store_type
      property :default_iiop_password
      property :default_iiop_user
      property :default_internal_servlets_disabled
      property :default_protocol
      property :default_secure_protocol
      property :default_tgiop_password
      property :default_tgiop_user
      property :dgc_idle_periods_until_timeout
      property :external_dns_name
      property :extra_ejbc_options
      property :extra_rmic_options
      property :gathered_writes_enabled
      property :graceful_shutdown_timeout
      property :health_check_interval_seconds
      property :health_check_start_delay_seconds
      property :health_check_timeout_seconds
      property :hosts_migratable_services
      property :httpd_enabled
      property :http_trace_support_enabled
      property :idle_connection_timeout
      property :idle_iiop_connection_timeout
      property :idle_periods_until_timeout
      property :ignore_sessions_during_shutdown
      property :iiop_enabled
      property :iiop_tx_mechanism
      property :instrument_stack_trace_enabled
      property :interface_address
      property :java_compiler_post_class_path
      property :java_compiler_pre_class_path
      property :java_compiler
      property :java_standard_trust_key_store_pass_phrase
      property :jdbcllr_table_name
      property :jdbc_logging_enabled
      property :jdbc_login_timeout_seconds
      property :jms_default_connection_factories_enabled
      property :jndi_transportable_object_factory_list
      property :key_stores
      property :listen_address
      property :listen_delay_secs
      property :listeners_bind_early
      property :listen_port_enabled
      property :listen_port
      property :listen_thread_start_delay_secs
      property :log_buffer_size_kb
      property :log_domain_log_broadcaster_buffer_size
      property :log_domain_log_broadcast_filter
      property :log_domain_log_broadcast_severity
      property :log_file_count
      property :log_file_name
      property :log_file_time_span
      property :login_timeout_millis
      property :log_log4j_logging_enabled
      property :log_file_filter
      property :log_file_rotation_dir
      property :log_file_severity
      property :log_logger_severity_properties
      property :log_logger_severity
      property :log_memory_buffer_filter
      property :log_memory_buffer_severity
      property :log_memory_buffer_size
      property :log_notes
      property :log_platform_logger_levels
      property :log_redirect_stderr_to_server_log_enabled
      property :log_redirect_stdout_to_server_log_enabled
      property :log_remote_exceptions_enabled
      property :log_rotate_log_on_startup
      property :log_rotation_time
      property :log_rotation_type
      property :log_server_logging_bridge_use_parent_loggers_enabled
      property :log_stdout_filter
      property :log_stdout_format
      property :log_stdout_log_stack
      property :log_stdout_severity
      property :low_memory_gc_threshold
      property :low_memory_granularity_level
      property :low_memory_sample_size
      property :low_memory_time_interval
      property :managed_server_independence_enabled
      property :max_com_message_size
      property :max_http_message_size
      property :max_iiop_message_size
      property :max_open_sock_count
      property :max_t3_message_size
      property :message_id_prefix_enabled
      property :messaging_bridge_thread_pool_size
      property :msi_file_replication_enabled
      property :muxer_class
      property :native_io_enabled
      property :nm_socket_create_timeout_in_millis
      property :notes
      property :outbound_enabled
      property :outbound_private_key_enabled
      property :period_length
      property :preferred_secondary_group
      property :print_stack_trace_in_production
      property :reliable_delivery_policy
      property :replication_group
      property :replication_ports
      property :resolve_dns_name
      property :restart_delay_seconds
      property :restart_interval_seconds
      property :reverse_dns_allowed
      property :scattered_reads_enabled
      property :server_life_cycle_timeout_val
      property :server_template
      property :server_version
      property :socket_buffer_size_as_chunk_size
      property :socket_readers
      property :ssl_accept_kss_demo_certs_enabled
      property :ssl_allow_unencrypted_null_cipher
      property :ssl_cert_authenticator
      property :ssl_ciphersuites
      property :ssl_client_cert_alias
      property :ssl_client_certificate_enforced
      property :ssl_client_cert_private_key_pass_phrase
      property :ssl_enabled
      property :ssl_export_key_lifespan
      property :ssl_hostname_verification_ignored
      property :ssl_hostname_verifier
      property :ssl_identity_and_trust_locations
      property :ssl_inbound_certificate_validation
      property :ssl_jsse_enabled
      property :ssl_listen_port
      property :ssl_login_timeout_millis
      property :ssl_notes
      property :ssl_outbound_certificate_validation
      property :ssl_outbound_private_key_alias
      # property :ssl_outbound_private_key_pass_phrase
      property :ssl_peer_validation_enforced
      property :ssl_server_certificate_chain_file_name
      property :ssl_server_certificate_file_name
      property :ssl_server_key_file_name
      property :ssl_server_private_key_alias
      property :ssl_server_private_key_pass_phrase
      property :ssl_rejection_logging_enabled
      property :ssl_trusted_ca_file_name
      property :ssl_two_way_ssl_enabled
      property :ssl_use_client_cert_for_outbound
      property :ssl_use_server_certs
      property :staging_directory_name
      property :staging_mode
      property :startup_mode
      property :startup_timeout
      property :stuck_thread_max_time
      property :stuck_thread_timer_interval
      property :tgiop_enabled
      property :thread_pool_percent_socket_readers
      property :transaction_log_file_prefix
      property :transaction_log_file_write_policy
      property :tunneling_client_ping_secs
      property :tunneling_client_timeout_secs
      property :tunneling_enabled
      property :upload_directory_name
      property :use81_style_execute_queues
      property :use_concurrent_queue_for_request_manager
      property :use_detailed_thread_name
      property :use_enhanced_increment_advisor
      property :use_enhanced_priority_queue_for_request_manager
      property :use_fusion_for_llr
      property :verbose_ejb_deployment_enabled
      property :virtual_machine_name
      property :xml_entity_cache
      property :xml_registry
      #
      # Weblogic 12.2.1 new properties
      #
      property :buzz_address
      property :buzz_enabled
      property :buzz_port
      property :eager_thread_local_cleanup
      property :jms_connection_factory_unmapped_res_ref_mode
      property :log_date_format_pattern
      property :log_monitoring_enabled
      property :log_monitoring_interval_secs
      property :log_monitoring_throttle_message_length
      property :log_monitoring_throttle_threshold
      property :log_tags
      property :max_concurrent_long_running_requests
      property :max_concurrent_new_threads
      property :num_of_retries_before_msi_mode
      property :retry_interval_before_msi_mode
      property :ssl_minimum_tls_protocol_version
      property :ssl_ss_lv2_hello_enabled
      property :ssl_tags
      property :tags
      #
      # Overload protection
      #
      property :overload_panic_action
      property :overload_shared_capacity_for_work_managers
      property :overload_failure_action
      property :overload_server_failure_trigger
      property :overload_free_memory_percent_low_threshold
      property :overload_free_memory_percent_high_threshold
      property :overload_notes
      property :overload_tags
      #
      # JTA Migration properties
      #
      property :migration_candidate_machines
      property :migration_post_script_failure_fatal
      property :migration_strict_ownership_check
      property :migration_pre_script
      property :migration_millis_to_sleep_between_attempts
      property :migration_critical
      property :migration_number_of_restart_attempts
      property :migration_policy
      property :migration_additional_migration_attempts
      property :migration_post_script
      property :migration_restart_on_failure
      property :migration_seconds_between_restarts
      property :migration_non_local_post_allowed
      property :migration_notes
      property :migration_tags
    end

    add_title_attributes(:server_name)

    private

    def create_boot_properties_file
      wls_config  = Puppet_X::EnterpriseModules::WebLogic::Tree.new(domain)
      domain_path = wls_config.get('/RootDirectory')
      os_user     = configuration.fetch(domain).fetch('user')
      username    = configuration.fetch(domain).fetch('weblogic_user')
      password    = configuration.fetch(domain).fetch('weblogic_password')
      top_dir     = "#{domain_path}/servers/#{server_name}"
      group_uid   = File.stat(domain_path).gid
      os_group    = Etc.getgrgid(group_uid).name
      dir_name    = "#{top_dir}/security"
      file_name   = "#{dir_name}/boot.properties"
      FileUtils.mkdir_p(dir_name)
      File.open(file_name, 'w') do |file|
        file.write("username=#{username}\n")
        file.write("password=#{password}\n")
      end
      Puppet.info "Creating #{file_name}."
      FileUtils.chown_R(os_user, os_group, top_dir)
      FileUtils.chmod_R(0o750, top_dir)
    end
  end
end
#
